@@ -335,7 +335,8 @@ def go(batch=False):
         return ''
     pid = read_file(home, file_name)
     if pid and get_pname(pid).find('whatap_python') >= 0:
-        return
+        os.kill(int(pid), signal.SIGKILL)
+        
     try:
         home_path= os.environ.get(home)
         if os.path.exists(os.path.join(home_path, AGENT_NAME)):
@@ -344,16 +345,14 @@ def go(batch=False):
         source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
                                   ARCH[platform.machine()])
 
-
         os.symlink(os.path.join(source_cwd, AGENT_NAME),
                    os.path.join(home_path, AGENT_NAME))
 
         newenv['whatap.enabled'] = 'True'
-        
-        process = subprocess.Popen('./{0}'.format(AGENT_NAME),
+        newenv['WHATAP_PID_FILE'] = file_name
+        process = subprocess.Popen(['./{0}'.format(AGENT_NAME), '-t', '3', '-d', '1'],
                                    cwd=home_path,env=newenv)
-        # Write PID file
-        write_file(home, file_name, str(process.pid))
+        process.wait()
     except Exception as e:
         import traceback
         traceback.print_exc()
